@@ -1,27 +1,36 @@
 <?php
-namespace Froxlor\Cron\Http\Php;
-
-use Froxlor\Database\Database;
-use Froxlor\Settings;
 
 /**
  * This file is part of the Froxlor project.
  * Copyright (c) 2010 the Froxlor Team (see authors).
  *
- * For the full copyright and license information, please view the COPYING
- * file that was distributed with this source code. You can also view the
- * COPYING file online at http://files.froxlor.org/misc/COPYING.txt
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * @copyright (c) the authors
- * @author Michael Kaufmann <mkaufmann@nutime.de>
- * @author Froxlor team <team@froxlor.org> (2010-)
- * @license GPLv2 http://files.froxlor.org/misc/COPYING.txt
- * @package Cron
- *         
- * @link http://www.nutime.de/
- * @since 0.9.16
- *       
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, you can also view it online at
+ * https://files.froxlor.org/misc/COPYING.txt
+ *
+ * @copyright  the authors
+ * @author     Froxlor team <team@froxlor.org>
+ * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
+
+namespace Froxlor\Cron\Http\Php;
+
+use Froxlor\Database\Database;
+use Froxlor\Domain\Domain;
+use Froxlor\FileDir;
+use Froxlor\PhpHelper;
+use Froxlor\Settings;
+
 class Fcgid
 {
 
@@ -30,14 +39,14 @@ class Fcgid
 	 *
 	 * @var array
 	 */
-	private $domain = array();
+	private $domain = [];
 
 	/**
 	 * Admin-Date cache array
 	 *
 	 * @var array
 	 */
-	private $admin_cache = array();
+	private $admin_cache = [];
 
 	/**
 	 * main constructor
@@ -54,7 +63,6 @@ class Fcgid
 	 */
 	public function createConfig($phpconfig)
 	{
-
 		// create starter
 		$starter_file = "#!/bin/sh\n\n";
 		$starter_file .= "#\n";
@@ -66,26 +74,26 @@ class Fcgid
 		$starter_file .= "export PHPRC\n";
 
 		// set number of processes for one domain
-		if ((int) $this->domain['mod_fcgid_starter'] != - 1) {
-			$starter_file .= "PHP_FCGI_CHILDREN=" . (int) $this->domain['mod_fcgid_starter'] . "\n";
+		if ((int)$this->domain['mod_fcgid_starter'] != -1) {
+			$starter_file .= "PHP_FCGI_CHILDREN=" . (int)$this->domain['mod_fcgid_starter'] . "\n";
 		} else {
-			if ((int) $phpconfig['mod_fcgid_starter'] != - 1) {
-				$starter_file .= "PHP_FCGI_CHILDREN=" . (int) $phpconfig['mod_fcgid_starter'] . "\n";
+			if ((int)$phpconfig['mod_fcgid_starter'] != -1) {
+				$starter_file .= "PHP_FCGI_CHILDREN=" . (int)$phpconfig['mod_fcgid_starter'] . "\n";
 			} else {
-				$starter_file .= "PHP_FCGI_CHILDREN=" . (int) Settings::Get('system.mod_fcgid_starter') . "\n";
+				$starter_file .= "PHP_FCGI_CHILDREN=" . (int)Settings::Get('system.mod_fcgid_starter') . "\n";
 			}
 		}
 
 		$starter_file .= "export PHP_FCGI_CHILDREN\n";
 
 		// set number of maximum requests for one domain
-		if ((int) $this->domain['mod_fcgid_maxrequests'] != - 1) {
-			$starter_file .= "PHP_FCGI_MAX_REQUESTS=" . (int) $this->domain['mod_fcgid_maxrequests'] . "\n";
+		if ((int)$this->domain['mod_fcgid_maxrequests'] != -1) {
+			$starter_file .= "PHP_FCGI_MAX_REQUESTS=" . (int)$this->domain['mod_fcgid_maxrequests'] . "\n";
 		} else {
-			if ((int) $phpconfig['mod_fcgid_maxrequests'] != - 1) {
-				$starter_file .= "PHP_FCGI_MAX_REQUESTS=" . (int) $phpconfig['mod_fcgid_maxrequests'] . "\n";
+			if ((int)$phpconfig['mod_fcgid_maxrequests'] != -1) {
+				$starter_file .= "PHP_FCGI_MAX_REQUESTS=" . (int)$phpconfig['mod_fcgid_maxrequests'] . "\n";
 			} else {
-				$starter_file .= "PHP_FCGI_MAX_REQUESTS=" . (int) Settings::Get('system.mod_fcgid_maxrequests') . "\n";
+				$starter_file .= "PHP_FCGI_MAX_REQUESTS=" . (int)Settings::Get('system.mod_fcgid_maxrequests') . "\n";
 			}
 		}
 
@@ -96,15 +104,46 @@ class Fcgid
 
 		// remove +i attribute, so starter can be overwritten
 		if (file_exists($this->getStarterFile())) {
-			\Froxlor\FileDir::removeImmutable($this->getStarterFile());
+			FileDir::removeImmutable($this->getStarterFile());
 		}
 
 		$starter_file_handler = fopen($this->getStarterFile(), 'w');
 		fwrite($starter_file_handler, $starter_file);
 		fclose($starter_file_handler);
-		\Froxlor\FileDir::safe_exec('chmod 750 ' . escapeshellarg($this->getStarterFile()));
-		\Froxlor\FileDir::safe_exec('chown ' . $this->domain['guid'] . ':' . $this->domain['guid'] . ' ' . escapeshellarg($this->getStarterFile()));
-		\Froxlor\FileDir::setImmutable($this->getStarterFile());
+		FileDir::safe_exec('chmod 750 ' . escapeshellarg($this->getStarterFile()));
+		FileDir::safe_exec('chown ' . $this->domain['guid'] . ':' . $this->domain['guid'] . ' ' . escapeshellarg($this->getStarterFile()));
+		FileDir::setImmutable($this->getStarterFile());
+	}
+
+	/**
+	 * fcgid-config directory
+	 *
+	 * @param boolean $createifnotexists
+	 *            create the directory if it does not exist
+	 *
+	 * @return string the directory
+	 */
+	public function getConfigDir($createifnotexists = true)
+	{
+		$configdir = FileDir::makeCorrectDir(Settings::Get('system.mod_fcgid_configdir') . '/' . $this->domain['loginname'] . '/' . $this->domain['domain'] . '/');
+
+		if (!is_dir($configdir) && $createifnotexists) {
+			FileDir::safe_exec('mkdir -p ' . escapeshellarg($configdir));
+			FileDir::safe_exec('chown ' . $this->domain['guid'] . ':' . $this->domain['guid'] . ' ' . escapeshellarg($configdir));
+		}
+
+		return $configdir;
+	}
+
+	/**
+	 * return path of php-starter file
+	 *
+	 * @return string the directory
+	 */
+	public function getStarterFile()
+	{
+		$starter_filename = FileDir::makeCorrectFile($this->getConfigDir() . '/php-fcgi-starter');
+		return $starter_filename;
 	}
 
 	/**
@@ -118,27 +157,28 @@ class Fcgid
 		$openbasedirc = ';';
 
 		if ($this->domain['openbasedir'] == '1') {
-
 			$openbasedirc = '';
 			$_phpappendopenbasedir = '';
 
 			$_custom_openbasedir = explode(':', Settings::Get('system.mod_fcgid_peardir'));
 			foreach ($_custom_openbasedir as $cobd) {
-				$_phpappendopenbasedir .= \Froxlor\Domain\Domain::appendOpenBasedirPath($cobd);
+				$_phpappendopenbasedir .= Domain::appendOpenBasedirPath($cobd);
 			}
 
 			$_custom_openbasedir = explode(':', Settings::Get('system.phpappendopenbasedir'));
 			foreach ($_custom_openbasedir as $cobd) {
-				$_phpappendopenbasedir .= \Froxlor\Domain\Domain::appendOpenBasedirPath($cobd);
+				$_phpappendopenbasedir .= Domain::appendOpenBasedirPath($cobd);
 			}
 
 			if ($this->domain['openbasedir_path'] == '0' && strstr($this->domain['documentroot'], ":") === false) {
-				$openbasedir = \Froxlor\Domain\Domain::appendOpenBasedirPath($this->domain['documentroot'], true);
+				$openbasedir = Domain::appendOpenBasedirPath($this->domain['documentroot'], true);
+			} else if ($this->domain['openbasedir_path'] == '2' && strpos(dirname($this->domain['documentroot']).'/', $this->domain['customerroot']) !== false) {
+				$openbasedir = Domain::appendOpenBasedirPath(dirname($this->domain['documentroot']).'/', true);
 			} else {
-				$openbasedir = \Froxlor\Domain\Domain::appendOpenBasedirPath($this->domain['customerroot'], true);
+				$openbasedir = Domain::appendOpenBasedirPath($this->domain['customerroot'], true);
 			}
 
-			$openbasedir .= \Froxlor\Domain\Domain::appendOpenBasedirPath($this->getTempDir());
+			$openbasedir .= Domain::appendOpenBasedirPath($this->getTempDir());
 			$openbasedir .= $_phpappendopenbasedir;
 		} else {
 			$openbasedir = 'none';
@@ -146,7 +186,7 @@ class Fcgid
 		}
 
 		$admin = $this->getAdminData($this->domain['adminid']);
-		$php_ini_variables = array(
+		$php_ini_variables = [
 			'SAFE_MODE' => 'Off', // keep this for compatibility, just in case
 			'PEAR_DIR' => Settings::Get('system.mod_fcgid_peardir'),
 			'TMP_DIR' => $this->getTempDir(),
@@ -158,75 +198,66 @@ class Fcgid
 			'OPEN_BASEDIR' => $openbasedir,
 			'OPEN_BASEDIR_C' => $openbasedirc,
 			'OPEN_BASEDIR_GLOBAL' => Settings::Get('system.phpappendopenbasedir'),
-			'DOCUMENT_ROOT' => \Froxlor\FileDir::makeCorrectDir($this->domain['documentroot']),
-			'CUSTOMER_HOMEDIR' => \Froxlor\FileDir::makeCorrectDir($this->domain['customerroot'])
-		);
+			'DOCUMENT_ROOT' => FileDir::makeCorrectDir($this->domain['documentroot']),
+			'CUSTOMER_HOMEDIR' => FileDir::makeCorrectDir($this->domain['customerroot'])
+		];
 
 		// insert a small header for the file
 		$phpini_file = ";\n";
 		$phpini_file .= "; php.ini created/changed on " . date("Y.m.d H:i:s") . " for domain '" . $this->domain['domain'] . "' with id #" . $this->domain['id'] . " from php template '" . $phpconfig['description'] . "' with id #" . $phpconfig['id'] . "\n";
 		$phpini_file .= "; Do not change anything in this file, it will be overwritten by the Froxlor Cronjob!\n";
 		$phpini_file .= ";\n\n";
-		$phpini_file .= \Froxlor\PhpHelper::replaceVariables($phpconfig['phpsettings'], $php_ini_variables);
+		$phpini_file .= PhpHelper::replaceVariables($phpconfig['phpsettings'], $php_ini_variables);
 		$phpini_file = str_replace('"none"', 'none', $phpini_file);
 		// $phpini_file = preg_replace('/\"+/', '"', $phpini_file);
 		$phpini_file_handler = fopen($this->getIniFile(), 'w');
 		fwrite($phpini_file_handler, $phpini_file);
 		fclose($phpini_file_handler);
-		\Froxlor\FileDir::safe_exec('chown root:0 ' . escapeshellarg($this->getIniFile()));
-		\Froxlor\FileDir::safe_exec('chmod 0644 ' . escapeshellarg($this->getIniFile()));
-	}
-
-	/**
-	 * fcgid-config directory
-	 *
-	 * @param boolean $createifnotexists
-	 *        	create the directory if it does not exist
-	 *        	
-	 * @return string the directory
-	 */
-	public function getConfigDir($createifnotexists = true)
-	{
-		$configdir = \Froxlor\FileDir::makeCorrectDir(Settings::Get('system.mod_fcgid_configdir') . '/' . $this->domain['loginname'] . '/' . $this->domain['domain'] . '/');
-
-		if (! is_dir($configdir) && $createifnotexists) {
-			\Froxlor\FileDir::safe_exec('mkdir -p ' . escapeshellarg($configdir));
-			\Froxlor\FileDir::safe_exec('chown ' . $this->domain['guid'] . ':' . $this->domain['guid'] . ' ' . escapeshellarg($configdir));
-		}
-
-		return $configdir;
+		FileDir::safe_exec('chown root:0 ' . escapeshellarg($this->getIniFile()));
+		FileDir::safe_exec('chmod 0644 ' . escapeshellarg($this->getIniFile()));
 	}
 
 	/**
 	 * fcgid-temp directory
 	 *
 	 * @param boolean $createifnotexists
-	 *        	create the directory if it does not exist
-	 *        	
+	 *            create the directory if it does not exist
+	 *
 	 * @return string the directory
 	 */
 	public function getTempDir($createifnotexists = true)
 	{
-		$tmpdir = \Froxlor\FileDir::makeCorrectDir(Settings::Get('system.mod_fcgid_tmpdir') . '/' . $this->domain['loginname'] . '/');
+		$tmpdir = FileDir::makeCorrectDir(Settings::Get('system.mod_fcgid_tmpdir') . '/' . $this->domain['loginname'] . '/');
 
-		if (! is_dir($tmpdir) && $createifnotexists) {
-			\Froxlor\FileDir::safe_exec('mkdir -p ' . escapeshellarg($tmpdir));
-			\Froxlor\FileDir::safe_exec('chown -R ' . $this->domain['guid'] . ':' . $this->domain['guid'] . ' ' . escapeshellarg($tmpdir));
-			\Froxlor\FileDir::safe_exec('chmod 0750 ' . escapeshellarg($tmpdir));
+		if (!is_dir($tmpdir) && $createifnotexists) {
+			FileDir::safe_exec('mkdir -p ' . escapeshellarg($tmpdir));
+			FileDir::safe_exec('chown -R ' . $this->domain['guid'] . ':' . $this->domain['guid'] . ' ' . escapeshellarg($tmpdir));
+			FileDir::safe_exec('chmod 0750 ' . escapeshellarg($tmpdir));
 		}
 
 		return $tmpdir;
 	}
 
 	/**
-	 * return path of php-starter file
+	 * return the admin-data of a specific admin
 	 *
-	 * @return string the directory
+	 * @param int $adminid
+	 *            id of the admin-user
+	 *
+	 * @return array
 	 */
-	public function getStarterFile()
+	private function getAdminData($adminid)
 	{
-		$starter_filename = \Froxlor\FileDir::makeCorrectFile($this->getConfigDir() . '/php-fcgi-starter');
-		return $starter_filename;
+		$adminid = intval($adminid);
+
+		if (!isset($this->admin_cache[$adminid])) {
+			$stmt = Database::prepare("
+					SELECT `email`, `loginname` FROM `" . TABLE_PANEL_ADMINS . "` WHERE `adminid` = :id");
+			$this->admin_cache[$adminid] = Database::pexecute_first($stmt, [
+				'id' => $adminid
+			]);
+		}
+		return $this->admin_cache[$adminid];
 	}
 
 	/**
@@ -236,29 +267,7 @@ class Fcgid
 	 */
 	public function getIniFile()
 	{
-		$phpini_filename = \Froxlor\FileDir::makeCorrectFile($this->getConfigDir() . '/php.ini');
+		$phpini_filename = FileDir::makeCorrectFile($this->getConfigDir() . '/php.ini');
 		return $phpini_filename;
 	}
-
-	/**
-	 * return the admin-data of a specific admin
-	 *
-	 * @param int $adminid
-	 *        	id of the admin-user
-	 *        	
-	 * @return array
-	 */
-	private function getAdminData($adminid)
-	{
-		$adminid = intval($adminid);
-
-		if (! isset($this->admin_cache[$adminid])) {
-			$stmt = Database::prepare("
-					SELECT `email`, `loginname` FROM `" . TABLE_PANEL_ADMINS . "` WHERE `adminid` = :id");
-			$this->admin_cache[$adminid] = Database::pexecute_first($stmt, array(
-				'id' => $adminid
-			));
-		}
-		return $this->admin_cache[$adminid];
-	}
 }
